@@ -564,6 +564,25 @@ def myNetworkEventLifecycleCallback(conn, net, event, detail, opaque):
                                                                  netEventToString(event),
                                                                  netDetailToString(event, detail)))
 
+##########################################################################
+# Storage pool events
+##########################################################################
+def storageEventToString(event):
+    storageEventStrings = ( "Defined",
+                            "Undefined",
+                            "Started",
+                            "Stopped",
+    )
+    return storageEventStrings[event]
+
+def myStoragePoolEventLifecycleCallback(conn, pool, event, detail, opaque):
+    print("myStoragePoolEventLifecycleCallback: Storage pool %s %s %d" % (pool.name(),
+                                                                          storageEventToString(event),
+                                                                          detail))
+
+def myStoragePoolEventRefreshCallback(conn, pool, opaque):
+    print("myStoragePoolEventRefreshCallback: Storage pool %s" % pool.name())
+
 ##########################################################################
 # Set up and run the program
 ##########################################################################
@@ -656,6 +675,9 @@ def main():
 
     vc.networkEventRegisterAny(None, libvirt.VIR_NETWORK_EVENT_ID_LIFECYCLE, myNetworkEventLifecycleCallback, None)
 
+    vc.storagePoolEventRegisterAny(None, libvirt.VIR_STORAGE_POOL_EVENT_ID_LIFECYCLE, myStoragePoolEventLifecycleCallback, None)
+    vc.storagePoolEventRegisterAny(None, libvirt.VIR_STORAGE_POOL_EVENT_ID_REFRESH, myStoragePoolEventRefreshCallback, None)
+
     vc.setKeepAlive(5, 3)
 
     # The rest of your app would go here normally, but for sake
