@@ -491,6 +491,7 @@ skip_impl = (
     'virDomainInterfaceAddresses',
     'virDomainGetPerfEvents',
     'virDomainSetPerfEvents',
+    'virDomainGetGuestVcpus',
 )
 
 lxc_skip_impl = (
@@ -522,6 +523,8 @@ skip_function = (
     'virConnectDomainEventDeregisterAny', # overridden in virConnect.py
     'virConnectNetworkEventRegisterAny',   # overridden in virConnect.py
     'virConnectNetworkEventDeregisterAny', # overridden in virConnect.py
+    'virConnectStoragePoolEventRegisterAny',   # overridden in virConnect.py
+    'virConnectStoragePoolEventDeregisterAny', # overridden in virConnect.py
     'virSaveLastError', # We have our own python error wrapper
     'virFreeError', # Only needed if we use virSaveLastError
     'virConnectListAllDomains', # overridden in virConnect.py
